#!/bin/sh
export PATH='/sbin:/bin:/usr/sbin:/usr/bin:/usr/games:/usr/local/sbin:/usr/local/bin:/root/bin'
echo 'name: optparse-applicative
version: 0.11.0.2
id: optparse-applicative-0.11.0.2-37d13171948a215acc4bdc8863a88f21
key: optpa_AycjlNbYzzrBcTeMabjNhH
license: BSD3
copyright: (c) 2012-2014 Paolo Capriotti <paolo@capriotti.io>
maintainer: paolo@capriotti.io
homepage: https://github.com/pcapriotti/optparse-applicative
synopsis: Utilities and combinators for parsing command line options
description:
    Here is a simple example of an applicative option parser:
    .
    @
    data Sample = Sample
    &#x20; &#x7b; hello :: String
    &#x20; , quiet :: Bool &#x7d;
    .
    sample :: Parser Sample
    sample = Sample
    &#x20; \<$\> strOption
    &#x20;     ( long \"hello\"
    &#x20;    \<\> metavar \"TARGET\"
    &#x20;    \<\> help \"Target for the greeting\" )
    &#x20; \<*\> switch
    &#x20;     ( long \"quiet\"
    &#x20;    \<\> help \"Whether to be quiet\" )
    @
    .
    The parser is built using applicative style starting from a set of basic
    combinators. In this example, @hello@ is defined as an '\''option'\'' with a
    @String@ argument, while @quiet@ is a boolean '\''flag'\'' (called '\''switch'\'').
    .
    A parser can be used like this:
    .
    @
    greet :: Sample -> IO ()
    greet (Sample h False) = putStrLn $ \"Hello, \" ++ h
    greet _ = return ()
    .
    main :: IO ()
    main = execParser opts \>\>= greet
    &#x20; where
    &#x20;   opts = info (helper \<*\> sample)
    &#x20;     ( fullDesc
    &#x20;    \<\> progDesc \"Print a greeting for TARGET\"
    &#x20;    \<\> header \"hello - a test for optparse-applicative\" )
    @
    .
    The @greet@ function is the entry point of the program, while @opts@ is a
    complete description of the program, used when generating a help text. The
    '\''helper'\'' combinator takes any parser, and adds a @help@ option to it (which
    always fails).
    .
    The @hello@ option in this example is mandatory (since it doesn'\''t have a
    default value), so running the program without any argument will display a
    help text:
    .
    >hello - a test for optparse-applicative
    >
    >Usage: hello --hello TARGET [--quiet]
    >  Print a greeting for TARGET
    >
    >Available options:
    >  -h,--help                Show this help text
    >  --hello TARGET           Target for the greeting
    >  --quiet                  Whether to be quiet
    .
    containing a short usage summary, and a detailed list of options with
    descriptions.
category: System
author: Paolo Capriotti
exposed: True
exposed-modules:
    Options.Applicative Options.Applicative.Arrows
    Options.Applicative.BashCompletion Options.Applicative.Builder
    Options.Applicative.Builder.Completer
    Options.Applicative.Builder.Internal Options.Applicative.Common
    Options.Applicative.Extra Options.Applicative.Help
    Options.Applicative.Help.Pretty Options.Applicative.Help.Chunk
    Options.Applicative.Help.Core Options.Applicative.Help.Types
    Options.Applicative.Types Options.Applicative.Internal
trusted: False
import-dirs: /usr/local/lib/cabal/ghc-7.10.2/optparse-applicative-0.11.0.2
library-dirs: /usr/local/lib/cabal/ghc-7.10.2/optparse-applicative-0.11.0.2
              /usr/local/lib
data-dir: /usr/local/share/cabal/ghc-7.10.2/optparse-applicative-0.11.0.2
hs-libraries: HSoptparse-applicative-0.11.0.2-AycjlNbYzzrBcTeMabjNhH
include-dirs: /usr/local/include
depends:
    ansi-wl-pprint-0.6.7.3-4a815b1272dc57cfe60d69f54f7bd0e8
    base-4.8.1.0-b8b97b99f1626bb4a12880f48ca36184
    process-1.2.3.0-d0490258ea9b7ac28566ea8dc1a5cc4a
    transformers-0.4.2.0-21dcbf13c43f5d8cf6a1f54dee6c5bff
    transformers-compat-0.4.0.4-3ca5cbcec233c17da785d5f27705643c
haddock-interfaces: /usr/local/share/doc/cabal/ghc-7.10.2/optparse-applicative-0.11.0.2/html/optparse-applicative.haddock
haddock-html: /usr/local/share/doc/cabal/ghc-7.10.2/optparse-applicative-0.11.0.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
